pub struct Debugger { /* private fields */ }Expand description
TUI Debugger for the i8051 emulator
Implementations
Sourceimpl Debugger
impl Debugger
Sourcepub fn new(config: DebuggerConfig) -> Result<Self>
pub fn new(config: DebuggerConfig) -> Result<Self>
Create a new debugger with the given configuration
Sourcepub fn tracing_collector(&self) -> TracingCollector
pub fn tracing_collector(&self) -> TracingCollector
Get a clone of the tracing collector that can be used as a Layer
Sourcepub fn breakpoints(&self) -> &BTreeSet<u32>
pub fn breakpoints(&self) -> &BTreeSet<u32>
Get a reference to the breakpoints set
Sourcepub fn breakpoints_mut(&mut self) -> &mut BTreeSet<u32>
pub fn breakpoints_mut(&mut self) -> &mut BTreeSet<u32>
Get a mutable reference to the breakpoints set
Sourcepub fn debugger_state(&self) -> DebuggerState
pub fn debugger_state(&self) -> DebuggerState
Get the current debugger state
Sourcepub fn toggle_breakpoint(&mut self, addr: u32)
pub fn toggle_breakpoint(&mut self, addr: u32)
Toggle a breakpoint at the given address
Sourcepub fn handle_event(
&mut self,
event: Event,
cpu: &mut Cpu,
ctx: &mut impl CpuContext,
) -> bool
pub fn handle_event( &mut self, event: Event, cpu: &mut Cpu, ctx: &mut impl CpuContext, ) -> bool
Handle a crossterm event and update internal state Returns true if we should step the CPU, false otherwise